unit Unit1;

interface

uses
  Windows, Messages, SysUtils, Variants, Classes, Graphics, Controls, Forms,
  Dialogs, StdCtrls;

const
  IMAGE_FORMAT_BMP = 1;
  IMAGE_FORMAT_EMF = 2;
  IMAGE_FORMAT_WMF = 3;
  IMAGE_FORMAT_JPG = 4;
  IMAGE_FORMAT_PNG = 5;
  IMAGE_FORMAT_GIF = 6;
  IMAGE_FORMAT_TIF = 7;
  IMAGE_FORMAT_PCX = 8;
  IMAGE_FORMAT_TGA = 9;
  IMAGE_FORMAT_JP2 = 10;
  IMAGE_FORMAT_RAS = 11;
  IMAGE_FORMAT_JPC = 12;
/////////////////////////////////////////////////////////////////////////////
//The compression method in the generated TIFF file.
  COMPRESSION_NONE		= 0;
  COMPRESSION_LZW		= 1;
  COMPRESSION_JPEG		= 2;
  COMPRESSION_PACKBITS	= 3;
  COMPRESSION_CCITTG4	= 4;
  COMPRESSION_CCITTG3	= 5;
  COMPRESSION_RLE		= 6;

/////////////////////////////////////////////////////////////////////////////
  BITCOUNT_1	= 1;	//black/white( 1 bits )
  BITCOUNT_4G	= 3;	//16 color grayscale( 4 bits )
  BITCOUNT_4	= 4;	//16 color( 4 bits )
  BITCOUNT_8G	= 7;	//256 color grayscale( 8 bits )
  BITCOUNT_8	= 8;	//256 color( 8 bits )
  BITCOUNT_24	= 24;	//True color( 24 bits )

type
  MBegin = function():Longint; stdcall;
  MEnd = function(id:Longint):Longint; stdcall;
  MConvert = function(id:Longint;infile:PChar;outpath:PChar;filename:PChar):Longint; stdcall;
  MSetParam = function(id:Longint;imagetype:Longint;bitcount:Longint;quality:Longint;rotate:Longint;width:Longint;height:Longint;xdpi:Longint;ydpi:Longint;compression:Longint;multipage:Longint):Longint; stdcall;

  TForm1 = class(TForm)
    Button1: TButton;
    Button2: TButton;
    procedure Button1Click(Sender: TObject);
    procedure Button2Click(Sender: TObject);
  private
    { Private declarations }
    m_hDll:HMODULE;
		pMBegin:MBegin;
		pMEnd:MEnd;
    pMConvert:MConvert;
    pMSetParam:MSetParam;

    function LoadDLL():BOOL;
    function FreeDLL():BOOL;    
  public
    { Public declarations }
  end;

var
  Form1: TForm1;

implementation

{$R *.dfm}
function TForm1.LoadDLL():BOOL;
var
   sDllFile: PAnsiChar;
   pFunc: FARPROC;
label
   ERR_FLAG;
begin
   sDllFile := 'pcltoimage.dll';
   m_hDll := LoadLibrary(sDllFile);
   if m_hDll = 0 then
   begin
      Result := FALSE;
      exit;
   end;

	 pFunc := GetProcAddress(m_hDll, 'MBegin');
	 if pFunc = nil then goto ERR_FLAG;
   pMBegin := pFunc;

	 pFunc := GetProcAddress(m_hDll, 'MEnd');
	 if pFunc = nil then goto ERR_FLAG;
   pMEnd := pFunc;

	 pFunc := GetProcAddress(m_hDll, 'MConvert');
	 if pFunc = nil then goto ERR_FLAG;
   pMConvert := pFunc;

	 pFunc := GetProcAddress(m_hDll, 'MSetParam');
	 if pFunc = nil then goto ERR_FLAG;
   pMSetParam := pFunc;

   Result := TRUE;
   exit;

ERR_FLAG:
   Result := FALSE;
end;

function TForm1.FreeDLL():BOOL;
begin
	if m_hDll <> 0  then
  begin
     FreeLibrary(m_hDll);
     m_hDll := 0;
  end;
	Result := TRUE;
end;

procedure TForm1.Button1Click(Sender: TObject);
var
  infile:PAnsiChar;
  outpath:PAnsiChar;
  id:Longint;

  imagetype:Longint;
  bitcount:Longint;
  quality:Longint;
  rotate:Longint;
  width:Longint;
  height:Longint;
  xdpi:Longint;
  ydpi:Longint;
  compression:Longint;
  multipage:Longint;
begin
	if LoadDLL() = FALSE then
  begin
    ShowMessage('Load pcltoimage.dll failed!');
		exit;
	end;

  infile := Pchar(ExtractFileDir(ParamStr(0))+'/test.pcl');
  outpath := Pchar(ExtractFileDir(ParamStr(0))+'/outpath/');

  id := pMBegin();
	if id > 0 then
  begin
		imagetype := IMAGE_FORMAT_TIF;
		bitcount := BITCOUNT_24;
		quality := 75;
		rotate := 0;
		width := 0;
		height := 0;
		xdpi := 150;
		ydpi := 150;
		compression := COMPRESSION_LZW;
		multipage := 1;
		//Set Output image param
		pMSetParam( id,imagetype,bitcount,quality,rotate,width,height,xdpi,ydpi,compression,multipage);

		//Convert to tiff file (multiple page)
		pMConvert(id,infile,outpath,'multiple');
		pMEnd(id);
  
		pMEnd(id);
	end;
  FreeDLL();
  ShowMessage('Convert finished!');
end;

procedure TForm1.Button2Click(Sender: TObject);
var
  infile:PAnsiChar;
  outpath:PAnsiChar;
  id:Longint;

  imagetype:Longint;
  bitcount:Longint;
  quality:Longint;
  rotate:Longint;
  width:Longint;
  height:Longint;
  xdpi:Longint;
  ydpi:Longint;
  compression:Longint;
  multipage:Longint;
begin
	if LoadDLL() = FALSE then
  begin
    ShowMessage('Load pcltoimage.dll failed!');
		exit;
	end;

  infile := Pchar(ExtractFileDir(ParamStr(0))+'/test.pcl');
  outpath := Pchar(ExtractFileDir(ParamStr(0))+'/outpath/');

  id := pMBegin();
	if id > 0 then
  begin
		imagetype := IMAGE_FORMAT_JPG;
		bitcount := BITCOUNT_8G;//256 color grayscale( 8 bits )
		quality := 85;
		rotate := 90;
		width := 1000;
		height := 800;
		xdpi := 200;
		ydpi := 200;
		//only for tiff
		compression := 0;
		multipage := 0;

		//Set Output image param
		pMSetParam( id,imagetype,bitcount,quality,rotate,width,height,xdpi,ydpi,compression,multipage);

		//Convert to jpg file
		pMConvert(id,infile,outpath,'jpg');
		pMEnd(id);
	end;
  FreeDLL();
  ShowMessage('Convert finished!');
end;

end.
 